##  Documenting SAP BTP Usage in the Application Landscape
Modeling SAP BTP in SAP LeanIX allows you understand where specific PaaS services from SAP BTP are used in your application landscape, which business capabilities rely on SAP BTP services. It helps you determine where within your application landscape the SAP BTP platform is used. Additionally, you can identify which parts of your organization or business units make use of SAP BTP.
Example reports:
![Application Matrix Report Showing Applications Grouped by Organizations](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2751a2df7a44101498b5d1cd28ac86be_LowRes.png)
Application Matrix Report Showing Applications Grouped by Organizations
![Application Landscape Report Showing All Applications Grouped by Business Capabilities](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274d91dd7a441014b3648a72a44c2bf0_LowRes.png)
Application Landscape Report Showing All Applications Grouped by Business Capabilities
You also get a complete overview of your SAP BTP account structure, including both global accounts and Subaccounts, and identify the individuals responsible for managing them. You can also list the services used in each Subaccount, track the adoption rate of BTP across different areas, and link business capabilities and processes to your SAP BTP services and components, especially those related to your Fiori applications.
Example reports:
![IT Component Landscape Report Detailing the SAP BTP PaaS Services Used Within Each Subaccount](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2748221c7a441014bc38a38dcfdfecf8_LowRes.png)
IT Component Landscape Report Detailing the SAP BTP PaaS Services Used Within Each Subaccount
![Matrix Report Showing Applications Mapped to BTP Platform Fact Sheet and Processes](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274af9947a44101498fdb83f28c81f73_LowRes.png)
Matrix Report Showing Applications Mapped to BTP Platform Fact Sheet and Processes
